#
# spec file for package flickcurl
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define sover 0
Name:           flickcurl
Version:        1.26
Release:        5.3
Summary:        Command-Line Tools for the Flickr Web Service
License:        LGPL-2.1-only
Group:          Productivity/Networking/Other
URL:            http://librdf.org/flickcurl/
Source:         http://download.dajobe.org/flickcurl/flickcurl-%{version}.tar.gz
Source1:        baselibs.conf
Source2:        flickcurl.changes
Source99:       flickcurl-rpmlintrc
# PATCH-FIX-UPSTREAM 0001-configure-Include-stdio.h-in-vsnprintf-check.patch fcrozat@suse.com -- add missing headers
Patch0:         0001-configure-Include-stdio.h-in-vsnprintf-check.patch
# PATCH-FIX-UPSTREAM 0001-Fix-Wimplicit-function-declaration.patch fcrozat@suse.com -- fix build with gcc14
Patch1:         0001-Fix-Wimplicit-function-declaration.patch
BuildRequires:  chrpath
BuildRequires:  curl
BuildRequires:  fdupes
BuildRequires:  libcurl-devel >= 7.10.0
BuildRequires:  libraptor-devel >= 2.0.0
BuildRequires:  libtool
BuildRequires:  pkgconfig
BuildRequires:  update-desktop-files
BuildRequires:  pkgconfig(glib-2.0)
BuildRequires:  pkgconfig(gobject-2.0)
BuildRequires:  pkgconfig(libxml-2.0)
BuildRoot:      %{_tmppath}/%{name}-%{version}-build

%description
Flickcurl is a C library for calling the Flickr Web service API. It handles the
API signing, token management, and parameter encoding and decoding, resulting
in C functions for the Web services APIs. It... uses libcurl to call the REST
Web service, and libxml2 to manipulate the XML responses. The library supports
reading photo, tag, and comments information, the photo upload and searching
APIs, and writing tags and comments. It provides utilities such as "flickcurl"
to exercise the API and "flickrdf" to get RDF metadata descriptions out of
photos, tags, and machine tags.

%package doc
Summary:        Documentation for flickcurl, a Flickr Web Service C library
Group:          Documentation/Other
Requires:       libflickcurl%{sover} = %{version}

%description doc
Flickcurl is a C library for calling the Flickr Web service API. It handles the
API signing, token management, and parameter encoding and decoding, resulting
in C functions for the Web services APIs. It... uses libcurl to call the REST
Web service, and libxml2 to manipulate the XML responses. The library supports
reading photo, tag, and comments information, the photo upload and searching
APIs, and writing tags and comments. It provides utilities such as "flickcurl"
to exercise the API and "flickrdf" to get RDF metadata descriptions out of
photos, tags, and machine tags.

This subpackage contains the developer documentation for %{name}.

%package -n libflickcurl%{sover}
Summary:        C Library API to the Flickr Web Service
Group:          System/Libraries

%description -n libflickcurl%{sover}
Flickcurl is a C library for calling the Flickr Web service API. It handles the
API signing, token management, and parameter encoding and decoding, resulting
in C functions for the Web services APIs. It... uses libcurl to call the REST
Web service, and libxml2 to manipulate the XML responses. The library supports
reading photo, tag, and comments information, the photo upload and searching
APIs, and writing tags and comments. It provides utilities such as "flickcurl"
to exercise the API and "flickrdf" to get RDF metadata descriptions out of
photos, tags, and machine tags.

%package -n libflickcurl-devel
Summary:        Development files for flickurl, a Flickr Web Service library
Group:          Development/Libraries/C and C++
Requires:       libcurl-devel
Requires:       libflickcurl%{sover} = %{version}
Requires:       libraptor-devel >= 1.4.0
Requires:       pkgconfig(libxml-2.0)

%description -n libflickcurl-devel
Flickcurl is a C library for calling the Flickr Web service API. It handles the
API signing, token management, and parameter encoding and decoding, resulting
in C functions for the Web services APIs. It... uses libcurl to call the REST
Web service, and libxml2 to manipulate the XML responses. The library supports
reading photo, tag, and comments information, the photo upload and searching
APIs, and writing tags and comments. It provides utilities such as "flickcurl"
to exercise the API and "flickrdf" to get RDF metadata descriptions out of
photos, tags, and machine tags.

%prep
%autosetup -p1

%build
%configure \
    --disable-static \

make %{?_smp_mflags}

%install
%make_install
%fdupes -s %{buildroot}

# Remove static libraries
find %{buildroot} -type f -name "*.la" -delete -print
#removing rpaths with chrpath
chrpath --delete %{buildroot}%{_bindir}/flickcurl
chrpath --delete %{buildroot}%{_bindir}/flickrdf

%post   -n libflickcurl%{sover} -p /sbin/ldconfig

%postun -n libflickcurl%{sover} -p /sbin/ldconfig

%files
%defattr(-,root,root)
%license LICENSE*
%doc AUTHORS ChangeLog NEWS* NOTICE README*
%{_bindir}/flickcurl
%{_bindir}/flickrdf
%{_mandir}/man1/flickcurl.1%{ext_man}
%{_mandir}/man1/flickrdf.1%{ext_man}

%files -n libflickcurl%{sover}
%defattr(-,root,root)
%license COPYING.LIB
%{_libdir}/libflickcurl.so.%{sover}
%{_libdir}/libflickcurl.so.%{sover}.*.*

%files -n libflickcurl-devel
%defattr(-,root,root)
%{_bindir}/flickcurl-config
%{_includedir}/flickcurl.h
%{_libdir}/libflickcurl.so
%{_libdir}/pkgconfig/flickcurl.pc
%{_mandir}/man1/flickcurl-config.1%{ext_man}

%files doc
%defattr(-,root,root)
%dir %{_datadir}/gtk-doc
%dir %{_datadir}/gtk-doc/html
%{_datadir}/gtk-doc/html/flickcurl

%changelog
* Tue Nov 12 2024 Frederic Crozat <fcrozat@suse.com>
- Backport 0001-Fix-Wimplicit-function-declaration.patch and
  0001-configure-Include-stdio.h-in-vsnprintf-check.patch from
  upstream to fix build with gcc14.
* Fri Mar 29 2024 Frederic Crozat <fcrozat@suse.com>
- Own gtk-doc directory to please RPM.
- Don't flag licenses as doc.
* Sat Oct  7 2017 jengelh@inai.de
- Avoid double shipping of documentation. Rectify RPM group
  and update summaries.
- %%_mandir is implicitly tagged %%doc already.
* Thu Oct  5 2017 fcrozat@suse.com
- Do not try to build gtk-doc, use the one from the tarball (drop
  BuildRequires gtk-doc).
- Remove unneeded BuildRequires automake / autoconf.
* Mon Nov 10 2014 fcrozat@suse.com
- Update to version 1.26:
  * Switch all API endpoints and image URLs to https protocol
  (http for Flickr API is deprecated since 2014-04-30).
  * Fixed utility documentation: args consistency for
  PER-PAGE / PAGE.
  * Added new extras: url_q, url_n and url_c for new image sizes.
  * Configuration and build improvements for newer automake and
  autoconf. Add new internal convienience libraries libmtwist and
  libgetopt.
  * Added build-time utility mangen to generate manpage and extras.
  * Generate and accept the new staticflickr.com domain for image
  URIs as well as the existing static.flickr.com.
  * Multiple error path allocation fixes, several memory leak
  fixes and a few overflows found via Coverity.
* Mon Apr 28 2014 fcrozat@suse.com
- Update for version 1.25:
  - more OAuth fixes, including uploading fully working
  - Multiple internal OAuth changes to simplify code.
- Remove flickcurl-wrong-memset.patch, merged upstream
* Sun Dec  9 2012 p.drouand@gmail.com
- Update to 1.23 version:
  * Full support using Flickr via OAuth 1.0 and converting
    from the legacy Flickr authentication to OAuth. It supports both
    authentication flows but Flickr has deprecated the legacy
    authentication, so it might stop working at any time.
  * Added an API call to upgrade from the Flickr legacy authentication to
    OAuth 1.0. This revokes and deletes the legacy 'auth_token' and returns
    an OAuth Access Token and Access Token Secret pair which need to be
    saved.
- New build dependencies: glib2 and gobject2.0
- Remove useless rpaths on the package
- Include really documentation into the two non-devel package to avoid break links
- Disable and remove statics libraries
* Tue Dec 27 2011 idonmez@suse.com
- Fix wrong size parameter in memset call
* Fri Dec 23 2011 andreas.stieger@gmx.de
- move non-documentation files from -doc to -devel to fix
  Factory build error with files packaged twice
* Sun Sep 18 2011 jengelh@medozas.de
- Apply packaging guidelines (remove redundant/obsolete
  tags/sections from specfile, etc.)
* Sat Aug  6 2011 crrodriguez@opensuse.org
- Fix build with newer curl Fix build with newer curl
* Mon Mar 28 2011 pascal.bleser@opensuse.org
- split out documentation into -doc subpackage, symlinked
- update to 1.21:
  * a memory leak when building photo list results was fixed
  * flickcurl_photos_setPerms() was fixed to allow false boolean permissions
  * flickcurl_photosets_getPhotos_params() was fixed to just work
  * the flickcurl(1) utility now handles Raptor V1, V2, or none
* Thu Nov 18 2010 pascal.bleser@opensuse.org
- update to 1.20:
  * fixes support for several major API calls that return standard photo
    responses (SPR), such as searching for photos, getting recent photos,
    listing photosets, and several others
* Sun Jul 25 2010 pascal.bleser@opensuse.org
- update to 1.19:
  * support was added for the new photosets APIs:
    + flickr.photosets.removePhotos
    + flickr.photosets.reorderPhotos
    + flickr.photosets.setPrimaryPhoto
  * support was added for photo notes when getting photo information
  * the flickcurl utility was updated to support all of the new APIs
* Tue Apr 27 2010 pascal.bleser@opensuse.org
- update to 1.18:
  * adds support for the (rest of the) Galleries API
  * adds a new People API call
  * adds new functions for controlling curl handle options
  * the flickcurl(1) utility was updated to support all of the new APIs
* Fri Mar  5 2010 pascal.bleser@opensuse.org
- update to 1.17:
  * support for the new stats API, the people API, the "photos of"
    people API, and the gallery API have been added
  * the flickcurl utility has been updated to support all of the
    new APIs
* Thu Jan 14 2010 pascal.bleser@opensuse.org
- update to 1.16:
  * the flickcurl utility configuration file generation was fixed
    to use a key=value format as documented
  * flickcurl now accepts files with spaces around the "="
  * the authentication documentation was updated to add a picture
    showing the result of fetching the mobile authentication URLs
* Sun Jan  3 2010 pascal.bleser@opensuse.org
- update to 1.15:
  * documentation updates
  * the flickcurl_search_params struct gained an in_gallery boolean
    field to restrict searches to photos in a gallery
  * the flickcurl utility photos.search commands gained
    geographical context, taking an integer argument for inside/
    outside, an is-commons boolean flag, and an is-gallery boolean
    flag
  * a few minor bugs and typographical errors were fixed
* Mon Sep 21 2009 pascal.bleser@opensuse.org
- update to 1.14:
  * adds a tutorial for using the search API along with a simple example program
  * adds support for search parameters (geo_context and is_commons) and new
    extras path_alias, url_m, url_o, url_s, url_sq, and url_t
  * fixes a few minor bugs and typos
* Sat Aug  1 2009 pascal.bleser@opensuse.org
- update to 1.13:
  * two new utility functions were added to
    + get photo IDs from "farm" image URLs
    + to get the current webservice delay time
  * requests were fixed to be dynamically allocated rather than use a fixed
    buffer
  * a resource leak bug for the HTTP user agent was fixed
* Sat Jul  4 2009 pascal.bleser@opensuse.org
- update to 1.12:
  * support for the two new collections API calls and four other new general
    API calls were added
  * functions were added for generating flic.kr short URIs for photos
  * a bug with resetting curl during sequences of mixed read and write API
    calls was fixed
  * the flickcurl(1) utility was updated to support the new API calls
  * several other minor improvements and fixes were made
* Tue May 26 2009 pascal.bleser@opensuse.org
- update to 1.11
* Fri May  1 2009 pascal.bleser@opensuse.org
- update to 1.10:
  * uploading images and replacing images was made to work again
  * functions were added to set the service URIs for the image upload and image
    replacing Web services
  * fixes were made to allow compiling and using the library from C++
* Sat Apr  4 2009 pascal.bleser@opensuse.org
- update to 1.9:
  * the Pandas API was added to get interesting photos from pandas
  * groups members get list method was added
  * some other minor bugfixes and improvements were made
- changes from 1.8:
  * the Places API was updated for 6 new API calls, including shape history
  * the Photos Geo API was updated for 5 new API calls for setting/getting
    locations
  * the Commons API was added with new support for 1 API call to get a list of
    institutions
  * some other minor fixes and improvements were also made
* Sun Nov 30 2008 guru@unixtech.be
- update to 1.7:
  * support for the new Machine Tags API was added, handling machine tag
    namespaces, predicates, and values
  * support for the updated Places API calls was added with access to ESRI
    shape data and URLs
  * support for the (not announced) flickr.tags.getClusterPhotos was added
  * some other minor fixes and improvements were made
* Thu Sep  4 2008 guru@unixtech.be
- added missing ldconfig post/postun scriptlets
- update to 1.6:
  * neighborhood place support was added
  * a new Photos List class was added to handle the standard result format
  * photos list results can now take a feed format parameter to return XML
    feed results
  * flickcurl_places_forUser support was added
  * the flickcurl utility was updated to help with authentication
  * many other minor fixes and improvements were made
* Sun Aug 17 2008 guru@unixtech.be
- update to 1.5:
  * support for the Tag Clusters API
  * new photo search API parameters contacts: has_geo, lat, lon, radius, and
    radius_units fields was added
* Wed Jun 25 2008 guru@unixtech.be
- new upstream version:
  * support for Flickr video in requests and responses was added
  * the recent API additions for getting content type, getting safety type,
    and getting geo perms were added to the library
  * a new RDF triples serializer class was added for turning photo metadata
    into RDF which uses new namespaces under machinetags.org/ns
* Fri Mar  7 2008 guru@unixtech.be
- new upstream version
* Mon Jan 28 2008 guru@unixtech.be
- new upstream version
* Sat Jan 12 2008 guru@unixtech.be
- new upstream version
* Tue Dec 25 2007 guru@unixtech.be
- rebuild against raptor 1.4.16
* Fri Dec 21 2007 guru@unixtech.be
- added AUTHORS and fdupes support
- made shared library policy compliant
- moved to Packman
* Sat Aug 11 2007 guru@unixtech.be
- new upstream version
* Fri Aug  3 2007 guru@unixtech.be
- new upstream version
* Mon Apr 16 2007 guru@unixtech.be
- new package
